@@ -69,10 +69,17 @@ def include_includes(parameters, model_fp):
     help="Do not update nomitall, just output parsed model json",
 )
 @click.option(
-    "-f", "--file", "model_fn", default="model.yaml", help="Model YAML file to deploy",
+    "-f",
+    "--file",
+    "model_fn",
+    default="model.yaml",
+    help="Model YAML file to deploy",
 )
 @click.option(
-    "-o", "--org", "org", help="UUID of the organization to publish the model as",
+    "-o",
+    "--org",
+    "org",
+    help="UUID of the organization to publish the model as",
 )
 @click.option(
     "-c",
@@ -183,7 +190,12 @@ def process_help(doc, key="root"):
                     help_files[key] = load_help_file(subele["file"])
                     doc[k] = {"key": key}
             else:
-                help_files.update(process_help(subele, key=".".join([key, k]),))
+                help_files.update(
+                    process_help(
+                        subele,
+                        key=".".join([key, k]),
+                    )
+                )
     return help_files
 
 
